Module structure

Module structure 

Structs

FiniteSubgroup

Traits

AbelianGroupSignature
AssociativeCompositionSignature
When composition is associative.
CancellativeCompositionSignature
CommutativeCompositionSignature
When composition is commutative.
CompositionSignature
A set with a binary operation of composition.
GroupSignature
When inverses always exist.
IdentitySignature
A set with a special element e called the identity element.
LeftCancellativeCompositionSignature
When compose(a, x) = compose(a, y) implies x = y for all a, x, y.
MetaAbelianGroupSignature
MetaAssociativeCompositionSignature
MetaCancellativeCompositionSignature
MetaCommutativeCompositionSignature
MetaCompositionSignature
MetaGroupSignature
MetaIdentitySignature
MetaLeftCancellativeCompositionSignature
MetaMonoidSignature
MetaRightCancellativeCompositionSignature
MetaTryInverseSignature
MetaTryLeftInverseSignature
MetaTryRightInverseSignature
MonoidSignature
When compose(x, e) = compose(e, x) = x for all x.
RightCancellativeCompositionSignature
When compose(x, a) = compose(y, a) implies x = y for all a, x, y.
TryInverseSignature
When the solution to compose(x, a) = compose(a, x) = e for x given a is unique whenever it exists.
TryLeftInverseSignature
When the solution to compose(x, a) = e for x given a is unique whenever it exists.
TryRightInverseSignature
When the solution to compose(a, x) = e for x given a is unique whenever it exists.